@@ -616,13 +616,13 @@ class RedisRoot:
             print(f'{datetime.datetime.now()} - '
                   f'Cached {django_model} successfully'
                   f'\n\n\n')
-        for func_name, performance_data in self.performance.items():
-            if func_name != 'enabled':
-                print(f'\n'
-                      f'{func_name}'
-                      f'Requests: {performance_data["requests"]}\n'
-                      f'Time: {performance_data["time"]}s\n'
-                      f'Per request: {performance_data["time"]/performance_data["requests"]}s')
+            for func_name, performance_data in self.performance.items():
+                if func_name != 'enabled':
+                    print(f'\n'
+                          f'{func_name}'
+                          f'Requests: {performance_data["requests"]}\n'
+                          f'Time: {performance_data["time"]}s\n'
+                          f'Per request: {performance_data["time"]/performance_data["requests"]}s')
 
 
     def fast_get_keys_values(self, string):
@@ -901,7 +901,7 @@ class RedisRoot:
                 value = value[field_to_filter]
             except KeyError as ex:
                 raise Exception(f'KeyError: {ex}\n'
-                                f'Info: {field_to_filter = }, {value = }\n'
+                                f'Info: {field_to_filter}, {value}\n'
                                 f'Maybe: deep filtering is not included on this model')
         allowed = self._filter_value(value, filter_type, filter_by)
         return allowed
@@ -910,7 +910,7 @@ class RedisRoot:
         allowed_list = [True]
         for filter_param in raw_filters.keys():
             filter_by = raw_filters[filter_param]
-            fields_to_filter, filter_type = self._split_filtering(redis_model, filter_param)
+            fields_to_filter, filter_type = self._split_filtering(filter_param)
             if field_name == fields_to_filter[0]:
                 fields_to_filter = fields_to_filter[1:]
                 allowed_list.append(self._filter(value, fields_to_filter, filter_type, filter_by))
